@@ -1,6 +1,6 @@
 # -*- coding: latin-1 -*-
 #
-# Copyright 2011-2020 Ghent University
+# Copyright 2011-2021 Ghent University
 #
 # This file is part of vsc-install,
 # originally created by the HPC team of Ghent University (http://ugent.be/hpc/en),
@@ -166,7 +166,7 @@ URL_GHUGENT_HPCUGENT = 'https://github.ugent.be/hpcugent/%(name)s'
 
 RELOAD_VSC_MODS = False
 
-VERSION = '0.17.2'
+VERSION = '0.17.8'
 
 log.info('This is (based on) vsc.install.shared_setup %s' % VERSION)
 log.info('(using setuptools version %s located at %s)' % (setuptools.__version__, setuptools.__file__))
@@ -228,6 +228,9 @@ KNOWN_LICENSES = {
 # a whitelist of licenses that allow pushing to pypi during vsc_release
 PYPI_LICENSES = ['LGPLv2+', 'GPLv2']
 
+# environment variable name to set when building rpms from vsc-install managed repos
+#    indicates the python version it is being build for
+VSC_RPM_PYTHON = 'VSC_RPM_PYTHON'
 
 def _fvs(msg=None):
     """
@@ -1257,7 +1260,7 @@ class vsc_setup(object):
             klass = _fvs('sanitize')
             return "\n    ".join([klass.sanitize(r) for r in name])
         else:
-            pyversuff = os.environ.get('VSC_RPM_PYTHON', None)
+            pyversuff = os.environ.get(VSC_RPM_PYTHON, None)
             if pyversuff in ("1", "2", "3"):
                 # enable VSC-style naming for Python packages: use 'python2-*' or 'python3-*',
                 # unless '1' is used as value for $VSC_RPM_PYTHON, then use 'python-*' for legacy behaviour
@@ -1363,6 +1366,11 @@ class vsc_setup(object):
         new_target['license'] = lic_name
         classifiers.append(lic_classifier)
 
+        # a dict with key the new_target key to search and replace
+        #    value is a list of 2-element (pattern, replace) lists passed to re.sub
+        #    if returning value is empty, it is not added after the replacement
+        vsc_filter_rpm = target.pop('vsc_filter_rpm', {})
+
         # set name, url, download_url (skip name if it was specified)
         update = self.get_name_url(version=target['version'], license_name=lic_name)
         if 'name' in target:
@@ -1424,7 +1432,7 @@ class vsc_setup(object):
 
         vsc_scripts = target.pop('vsc_scripts', True)
         if vsc_scripts:
-            candidates = self.generate_scripts()
+            candidates = self.generate_scripts(exclude=['__pycache__'])
             if candidates:
                 if 'scripts' in target:
                     old_scripts = target.pop('scripts', [])
@@ -1479,6 +1487,10 @@ class vsc_setup(object):
             tests_requires.append('isort < 5.0')
         else:
             tests_requires.extend([
+                # stick to older flake8, to avoid version conflict on pyflakes dependency
+                # flake8 3.9.0 requires pyflakes<2.4.0,>=2.3.0
+                # prospector 1.3.1 requires pyflakes<2.3.0,>=2.2.0
+                'flake8 < 3.9.0',
                 'prospector',
                 'mock',
             ])
@@ -1513,8 +1525,30 @@ class vsc_setup(object):
                     new_target['dependency_links'] += [''.join([git_scheme, url, '/hpcugent/', dep_name, '.git#egg=',
                                                                 dep_name_version])]
 
+        if VSC_RPM_PYTHON in os.environ:
+            for key, pattern_replace_list in vsc_filter_rpm.items():
+                def search_replace(txt):
+                    for pattern, replace in pattern_replace_list:
+                        txt = re.sub(pattern, replace, txt)
+                    return txt
+
+                if key in new_target:
+                    log.debug("Found VSC_RPM_PYTHON set and vsc_filter_rpm for %s set to %s", key, pattern_replace_list)
+                    old = new_target.pop(key)
+                    if isinstance(old, list):
+                        # remove empty strings
+                        new = [y for y in [search_replace(x) for x in old] if y]
+                    else:
+                        log.error("vsc_filter_rpm does not support %s for %s", type(old), key)
+                        sys.exit(1)
+                    if new:
+                        log.debug("new vsc_filter_rpm value for %s: %s", key, new)
+                        new_target[key] = new
+                    else:
+                        log.debug("new vsc_filter_rpm value for %s was empty, not adding it back", key)
+
         log.debug("New target = %s" % (new_target))
-        print(new_target)
+        print("new target", new_target)
         return new_target
 
     @staticmethod
@@ -1567,7 +1601,6 @@ class vsc_setup(object):
             exclude files provided by packages that are shared
                 excluded_pkgs_rpm: is a list of packages, default to ['vsc']
                 set it to None when defining own function
-            generate the setup.cfg using build_setup_cfg_for_bdist_rpm
         """
         pkgs = target.pop('excluded_pkgs_rpm', ['vsc'])
         if pkgs is not None:
@@ -1578,7 +1611,6 @@ class vsc_setup(object):
         # therefor we regenerate self.package files with the excluded pkgs as extra param
         self.package_files = self.files_in_packages(excluded_pkgs=pkgs)
         _fvs('prepare_rpm').SHARED_TARGET['packages'] = self.generate_packages()
-        self.build_setup_cfg_for_bdist_rpm(target)
 
     def action_target(self, target, setupfn=None, extra_sdist=None, urltemplate=None):
         """
@@ -1609,8 +1641,12 @@ class vsc_setup(object):
             self.cleanup()
 
         self.prepare_rpm(target)
-        x = self.parse_target(target, urltemplate)
-        setupfn(**x)
+
+        new_target = self.parse_target(target, urltemplate)
+        # generate the setup.cfg using build_setup_cfg_for_bdist_rpm
+        self.build_setup_cfg_for_bdist_rpm(new_target)
+
+        setupfn(**new_target)
 
 # here for backwards compatibility
 SHARED_TARGET = _fvs('SHARED_TARGET').SHARED_TARGET
